@@ -73,16 +73,17 @@ class Worker(QObject):
         all_image_types = list[list[str]]()
         conf.path.mkdir(parents=True, exist_ok=False)
 
-        if conf.cookies.is_file():
-            with Session() as sess:
-                sess.cookies.update(cookiejar_from_dict(json.loads(conf.cookies.read_text())))
-                base_page = sess.get('https://slow.pics/comparison')
-                if base_page.text.find('id="logoutBtn"') == -1:
-                    self.progress_status.emit(conf.uuid, 'Session Expired', 0, 0)
-                    raise StopIteration
-                conf.cookies.write_text(json.dumps(dict_from_cookiejar(sess.cookies)))
-
         try:
+            if conf.cookies.is_file():
+                with Session() as sess:
+                    sess.cookies.update(cookiejar_from_dict(json.loads(conf.cookies.read_text())))
+                    base_page = sess.get('https://slow.pics/comparison')
+                    if base_page.text.find('id="logoutBtn"') == -1:
+                        self.progress_status.emit(conf.uuid, 'Session Expired', 0, 0)
+                        logging.warning(f'slow.pics session expired, either login again or delete `{conf.cookies}`.')
+                        raise StopIteration
+                    conf.cookies.write_text(json.dumps(dict_from_cookiejar(sess.cookies)))
+
             for i, output in enumerate(conf.outputs):
                 if self.isFinished():
                     raise StopIteration
@@ -309,11 +310,15 @@ class FindFramesWorker(QObject):
                 )
                 _rnum_checked.add(rnum)
 
+                if conf.main.timeline.mode == conf.main.timeline.Mode.FRAME:
+                    frames = [out.prepared.clip[rnum] for out in conf.outputs]
+                else:
+                    time = conf.outputs[0].to_time(rnum)
+                    frames = [out.prepared.clip[int(out.to_frame(time))] for out in conf.outputs]
+
                 if all(
                     get_prop(f.props, '_PictType', str, None, '').encode() in picture_types_b
-                    for f in vs.core.std.Splice(
-                        [out.prepared.clip[rnum] for out in conf.outputs], True
-                    ).frames(close=True)
+                    for f in vs.core.std.Splice(frames, True).frames(close=True)
                 ):
                     break
 
